timeseries.curve_geometry
=========================

.. automodule:: timeseries.curve_geometry

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cdist
      cleanup
      contour_crossings
      euclidean
      frenet_frame
      frenet_kappa_tau
      mollifier
      mollifier_uneven
      secant_arclength
      secant_derivative
      secant_jump
      similarity_matrix
      tangent_arclength
   
   

   
   
   

   
   
   